import { StorageConfig } from './storage/types.js';
import { SearchOptions } from './search/types.js';
export interface Entity {
    name: string;
    entityType: string;
    observations: string[];
    tags: string[];
}
export interface Relation {
    from: string;
    to: string;
    relationType: string;
}
export interface KnowledgeGraph {
    entities: Entity[];
    relations: Relation[];
}
export declare class KnowledgeGraphManager {
    private storage;
    private searchManager;
    private config;
    constructor(storageConfig?: StorageConfig);
    private initializeStorage;
    private initializeSearchManager;
    private getStorageConfigFromEnv;
    private loadGraph;
    private saveGraph;
    /**
     * Close storage connections and cleanup resources
     */
    close(): Promise<void>;
    /**
     * Health check for the storage provider
     */
    healthCheck(): Promise<boolean>;
    createEntities(entities: Entity[], project?: string): Promise<Entity[]>;
    createRelations(relations: Relation[], project?: string): Promise<Relation[]>;
    addObservations(observations: {
        entityName: string;
        observations: string[];
    }[], project?: string): Promise<{
        entityName: string;
        addedObservations: string[];
    }[]>;
    deleteEntities(entityNames: string[], project?: string): Promise<void>;
    deleteObservations(deletions: {
        entityName: string;
        observations: string[];
    }[], project?: string): Promise<void>;
    deleteRelations(relations: Relation[], project?: string): Promise<void>;
    readGraph(project?: string): Promise<KnowledgeGraph>;
    searchNodes(query: string, optionsOrProject?: SearchOptions | {
        exactTags?: string[];
        tagMatchMode?: 'any' | 'all';
    } | string, project?: string): Promise<KnowledgeGraph>;
    openNodes(names: string[], project?: string): Promise<KnowledgeGraph>;
    /**
     * Add tags to existing entities
     */
    addTags(updates: {
        entityName: string;
        tags: string[];
    }[], project?: string): Promise<{
        entityName: string;
        addedTags: string[];
    }[]>;
    /**
     * Remove specific tags from entities
     */
    removeTags(updates: {
        entityName: string;
        tags: string[];
    }[], project?: string): Promise<{
        entityName: string;
        removedTags: string[];
    }[]>;
    /**
     * Helper method to build a filtered graph with relations
     */
    private buildFilteredGraph;
}
//# sourceMappingURL=core.d.ts.map