import { StorageProvider, MigrationService } from './types.js';
/**
 * Service for migrating data between different storage providers
 */
export declare class DataMigrationService implements MigrationService {
    /**
     * Migrate data between two storage providers
     */
    migrateFromStorage(project: string, sourceStorage: StorageProvider, targetStorage: StorageProvider): Promise<void>;
    /**
     * Validate that migration was successful by comparing data
     */
    validateMigration(project: string, sourceStorage: StorageProvider, targetStorage: StorageProvider): Promise<boolean>;
    /**
     * Backup data from a storage provider to a backup location
     */
    backupData(project: string, sourceStorage: StorageProvider, backupStorage: StorageProvider): Promise<void>;
    /**
     * Restore data from a backup
     */
    restoreData(backupProject: string, targetProject: string, backupStorage: StorageProvider, targetStorage: StorageProvider): Promise<void>;
    /**
     * List all projects in a storage provider
     */
    listProjects(_storage: StorageProvider): Promise<string[]>;
    /**
     * Get statistics about a project in a storage provider
     */
    getProjectStats(project: string, storage: StorageProvider): Promise<{
        entities: number;
        relations: number;
        size?: number;
    }>;
}
//# sourceMappingURL=migration.d.ts.map